@@ -8,17 +8,16 @@
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
+#include <cgraph/alloc.h>
 #include <glcomp/glcompimage.h>
 #include <glcomp/glcompfont.h>
 #include <glcomp/glcompset.h>
 #include <glcomp/glutils.h>
 #include <glcomp/glcomptexture.h>
-#include <common/memory.h>
 
 glCompImage *glCompImageNew(glCompObj * par, GLfloat x, GLfloat y)
 {
-    glCompImage *p;
-    p = NEW(glCompImage);
+    glCompImage *p = gv_alloc(sizeof(glCompImage));
     glCompInitCommon((glCompObj *) p, par, x, y);
     p->objType = glImageObj;
 
@@ -87,7 +86,7 @@ int glCompImageLoadPng(glCompImage * i, char *pngFile,int is2D)
 
 void glCompImageDraw(void *obj)
 {
-    glCompImage *p = (glCompImage *) obj;
+    glCompImage *p = obj;
     glCompCommon ref = p->common;
     GLfloat w,h,d;
 
@@ -106,7 +105,7 @@ void glCompImageDraw(void *obj)
     {
 	w = p->width;
 	h = p->height;
-	d=(GLfloat)p->common.layer* (GLfloat)GLCOMPSET_BEVEL_DIFF;
+	d=(GLfloat)p->common.layer * GLCOMPSET_BEVEL_DIFF;
 	glDisable(GL_BLEND);
 	glEnable(GL_TEXTURE_2D);
 	glTexEnvf (GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_DECAL);
