@@ -8,18 +8,14 @@
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
-#ifndef TREE_MAP_H
-#define TREE_MAP_H
+#pragma once
 
 #include <sparse/SparseMatrix.h>
+#include <stddef.h>
 
-typedef struct rectangle_struct {
-  real x[2];/* center */
-  real size[2]; /* total width/height*/
+typedef struct {
+  double x[2];/* center */
+  double size[2]; /* total width/height*/
 } rectangle;
 
-extern rectangle* tree_map(int n, real *area, rectangle fillrec);
-
-extern rectangle rectangle_new(real x, real y, real width, real height);
-
-#endif
+extern rectangle* tree_map(size_t n, double *area, rectangle fillrec);
