@@ -122,17 +122,11 @@ extern "C" {
 #define SF_STRING	0000004	/* a string stream                      */
 
 #define SF_APPENDWR	0000010	/* file is in append mode only.         */
-#if defined(_mac_SF_APPEND) && !_mac_SF_APPEND
-#define SF_APPEND	SF_APPENDWR	/* this was the original append bit */
-    /* but BSDI stat.h now uses this symbol. */
-    /* So we leave it out in such cases.    */
-#endif
 
 #define SF_MALLOC	0000020	/* buffer is malloc-ed                  */
 #define SF_LINE		0000040	/* line buffering                       */
 #define SF_SHARE	0000100	/* stream with shared file descriptor   */
 #define SF_EOF		0000200	/* eof was detected                     */
-#define SF_ERROR	0000400	/* an error happened                    */
 #define SF_STATIC	0001000	/* a stream that cannot be freed        */
 #define SF_IOCHECK	0002000	/* call exceptf before doing IO         */
 #define SF_PUBLIC	0004000	/* SF_SHARE and follow physical seek    */
